"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var ion_js_1 = require("ion-js");
var registerSuite = intern.getPlugin('interface.object').registerSuite;
var assert = intern.getPlugin('chai').assert;
var fs_1 = require("fs");
var IonHash_1 = require("../src/IonHash");
var testutil_1 = require("./testutil");
var TestValue = (function () {
    function TestValue(inputValue) {
        this.inputValue = inputValue;
        this.validIon = null;
        if (this.inputValue.startsWith(TestValue.ionPrefix)) {
            this.validIon = true;
            this.inputValue = this.inputValue.substring(TestValue.ionPrefix.length);
        }
        if (this.inputValue.startsWith(TestValue.invalidIonPrefix)) {
            this.validIon = false;
            this.inputValue = this.inputValue.substring(TestValue.invalidIonPrefix.length);
        }
    }
    TestValue.prototype.symbol = function () {
        var s = this.inputValue;
        s = s.replace(/\\/g, '\\\\');
        s = s.replace(/'/g, "\\'");
        return "\'" + s + "\'";
    };
    TestValue.prototype.string = function () {
        var s = this.inputValue;
        s = s.replace(/\\/g, '\\\\');
        s = s.replace(/"/g, '\\\"');
        return "\"" + s + "\"";
    };
    TestValue.prototype.long_string = function () {
        var s = this.inputValue;
        s = s.replace(/\\/g, '\\\\');
        s = s.replace(/'/g, "\\'");
        return "'''" + s + "'''";
    };
    TestValue.prototype.clob = function () {
        var buffer = Buffer.from(this.string(), 'utf8');
        var sb = '';
        for (var i = 0; i < buffer.length; i++) {
            var b = buffer[i];
            if (b >= 128) {
                sb += "\\x" + b.toString(16);
            }
            else {
                sb += String.fromCharCode(b);
            }
        }
        return '{{' + sb + '}}';
    };
    TestValue.prototype.blob = function () {
        var buffer = Buffer.from(this.inputValue, 'utf8');
        return '{{' + buffer.toString('base64') + '}}';
    };
    TestValue.ionPrefix = 'ion::';
    TestValue.invalidIonPrefix = 'invalid_ion::';
    return TestValue;
}());
var suite = {};
(0, fs_1.readFileSync)('ion-hash-test/big_list_of_naughty_strings.txt', 'utf-8')
    .split(/\r?\n/)
    .filter(function (line) { return !(line == '' || line[0] == '#'); })
    .forEach(function (line) {
    var tv = new TestValue(line);
    var strings = [];
    strings.push(tv.symbol());
    strings.push(tv.string());
    strings.push(tv.long_string());
    strings.push(tv.clob());
    strings.push(tv.blob());
    strings.push(tv.symbol() + "::" + tv.symbol());
    strings.push(tv.symbol() + "::" + tv.string());
    strings.push(tv.symbol() + "::" + tv.long_string());
    strings.push(tv.symbol() + "::" + tv.clob());
    strings.push(tv.symbol() + "::" + tv.blob());
    strings.push(tv.symbol() + "::{" + tv.symbol() + ":" + tv.symbol() + "}");
    strings.push(tv.symbol() + "::{" + tv.symbol() + ":" + tv.string() + "}");
    strings.push(tv.symbol() + "::{" + tv.symbol() + ":" + tv.long_string() + "}");
    strings.push(tv.symbol() + "::{" + tv.symbol() + ":" + tv.clob() + "}");
    strings.push(tv.symbol() + "::{" + tv.symbol() + ":" + tv.blob() + "}");
    if (tv.validIon) {
        strings.push(tv.inputValue);
        strings.push(tv.symbol() + "::" + tv.inputValue);
        strings.push(tv.symbol() + "::{" + tv.symbol() + ":" + tv.inputValue + "}");
        strings.push(tv.symbol() + "::{" + tv.symbol() + ":" + tv.symbol() + "::" + tv.inputValue + "}");
    }
    strings.push(tv.symbol() + "::["
        + tv.symbol() + ", "
        + tv.string() + ", "
        + tv.long_string() + ", "
        + tv.clob() + ", "
        + tv.blob() + ", "
        + (tv.validIon ? tv.inputValue : '')
        + "]");
    strings.push(tv.symbol() + "::("
        + tv.symbol() + " "
        + tv.string() + " "
        + tv.long_string() + " "
        + tv.clob() + " "
        + tv.blob() + " "
        + (tv.validIon ? tv.inputValue : '')
        + ")");
    strings.push(tv.symbol() + "::" + tv.symbol() + "::" + tv.symbol() + "::" + tv.string());
    strings.forEach(function (str) {
        suite[str] = function () { return runTest(tv, str); };
    });
});
registerSuite('BigListOfNaughtyStringsTests', suite);
function runTest(tv, testString) {
    var hashWriter;
    try {
        var reader = (0, ion_js_1.makeReader)(testString);
        hashWriter = (0, IonHash_1.makeHashWriter)((0, ion_js_1.makeBinaryWriter)(), (0, testutil_1.testHasherProvider)('md5'));
        reader.next();
        hashWriter.writeValue(reader);
    }
    catch (e) {
        (0, testutil_1.writeln)(e);
        if (tv.validIon) {
            throw e;
        }
    }
    var hashReader;
    try {
        var reader = (0, ion_js_1.makeReader)(testString);
        hashReader = (0, IonHash_1.makeHashReader)(reader, (0, testutil_1.testHasherProvider)('md5'));
        hashReader.next();
        hashReader.next();
    }
    catch (e) {
        (0, testutil_1.writeln)(e);
        if (tv.validIon) {
            throw e;
        }
    }
    if (tv.validIon == null || tv.validIon) {
        var writerDigest = (0, testutil_1.toHexString)(hashWriter.digest());
        assert.deepEqual(writerDigest, (0, testutil_1.toHexString)(hashReader.digest()));
        assert.deepEqual(writerDigest, (0, testutil_1.toHexString)((0, IonHash_1.digest)((0, ion_js_1.load)(testString), 'md5')));
    }
}
//# sourceMappingURL=BigListOfNaughtyStringsTests.js.map