"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var ion_js_1 = require("ion-js");
var registerSuite = intern.getPlugin('interface.object').registerSuite;
var assert = intern.getPlugin('chai').assert;
var IonHash_1 = require("../src/IonHash");
var testutil_1 = require("./testutil");
registerSuite('CryptoHasherProviderTests', {
    cryptoMD5reader: function () { return testReader('[1, 2, {a: 3, b: (4 {c: 5} 6) }, 7]', 'dd 20 84 69 9a 2e 85 fe ef 64 c8 79 57 b6 9f cd'); },
    cryptoMD5readerStructWithMultipleScalarFields: function () { return testReader('{a: 1, b: 2}', '52 30 a3 c4 0d a0 d5 95 28 bb e5 01 90 f4 0c 23'); },
    cryptoMD5writer: function () {
        var expectedIon = '[1,2,{a:3,b:(4 {c:5} 6)},7]';
        var expectedDigest = 'dd 20 84 69 9a 2e 85 fe ef 64 c8 79 57 b6 9f cd';
        var writer = (0, ion_js_1.makeTextWriter)();
        var hashWriter = (0, IonHash_1.makeHashWriter)(writer, (0, IonHash_1.cryptoHasherProvider)('md5'));
        hashWriter.stepIn(ion_js_1.IonTypes.LIST);
        hashWriter.writeInt(1);
        hashWriter.writeInt(2);
        hashWriter.stepIn(ion_js_1.IonTypes.STRUCT);
        hashWriter.writeFieldName('a');
        hashWriter.writeInt(3);
        hashWriter.writeFieldName('b');
        hashWriter.stepIn(ion_js_1.IonTypes.SEXP);
        hashWriter.writeInt(4);
        hashWriter.stepIn(ion_js_1.IonTypes.STRUCT);
        hashWriter.writeFieldName('c');
        hashWriter.writeInt(5);
        hashWriter.stepOut();
        hashWriter.writeInt(6);
        hashWriter.stepOut();
        hashWriter.stepOut();
        hashWriter.writeInt(7);
        hashWriter.stepOut();
        var actualDigest = hashWriter.digest();
        assert.equal((0, testutil_1.toHexString)(actualDigest), expectedDigest);
        assert.equal(String.fromCharCode.apply(null, hashWriter.getBytes()), expectedIon);
        assert.equal(String.fromCharCode.apply(null, writer.getBytes()), expectedIon);
    },
    unknownAlgorithm: function () {
        assert.throws(function () {
            (0, IonHash_1.makeHashWriter)((0, ion_js_1.makeTextWriter)(), (0, IonHash_1.cryptoHasherProvider)('unknownAlgorithm'));
        });
    },
});
function testReader(input, expectedDigest) {
    var hashReader = (0, IonHash_1.makeHashReader)((0, ion_js_1.makeReader)(input), (0, IonHash_1.cryptoHasherProvider)('md5'));
    hashReader.next();
    hashReader.next();
    var actualDigest = hashReader.digest();
    assert.equal((0, testutil_1.toHexString)(actualDigest), expectedDigest);
}
//# sourceMappingURL=CryptoHasherProviderTest.js.map