"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var ion_js_1 = require("ion-js");
var registerSuite = intern.getPlugin('interface.object').registerSuite;
var assert = intern.getPlugin('chai').assert;
var IonHash_1 = require("../src/IonHash");
var testutil_1 = require("./testutil");
registerSuite('FieldnameBehavior', {
    null: function () { test("null", "(0x0b 0x0f 0x0e)"); },
    bool: function () { test("false", "(0x0b 0x10 0x0e)"); },
    int: function () { test("5", "(0x0b 0x20 0x05 0x0e)"); },
    float: function () { test("2e0", "(0x0b 0x40 0x40 0x00 0x00 0x00 0x00 0x00 0x00 0x00 0x0e)"); },
    decimal: function () { test("1234.500", "(0x0b 0x50 0xc3 0x12 0xd6 0x44 0x0e)"); },
    timestamp: function () { test("2017-01-01T00:00:00Z", "(0x0b 0x60 0x80 0x0f 0xe1 0x81 0x81 0x80 0x80 0x80 0x0e)"); },
    symbol: function () { test("hi", "(0x0b 0x70 0x68 0x69 0x0e)"); },
    string: function () { test("\"hi\"", "(0x0b 0x80 0x68 0x69 0x0e)"); },
    clob: function () { test("{{\"hi\"}}", "(0x0b 0x90 0x68 0x69 0x0e)"); },
    blob: function () { test("{{aGVsbG8=}}", "(0x0b 0xa0 0x68 0x65 0x6c 0x6c 0x6f 0x0e)"); },
    list: function () { test("[1,2,3]", "(0x0b 0xb0 0x0b 0x20 0x01 0x0e 0x0b 0x20 0x02 0x0e 0x0b 0x20 0x03 0x0e 0x0e)"); },
    sexp: function () { test("(1 2 3)", "(0x0b 0xc0 0x0b 0x20 0x01 0x0e 0x0b 0x20 0x02 0x0e 0x0b 0x20 0x03 0x0e 0x0e)"); },
    struct: function () {
        test("{a:1,b:2,c:3}", "(0x0b 0xd0"
            + "   0x0c 0x0b 0x70 0x61 0x0c 0x0e 0x0c 0x0b 0x20 0x01 0x0c 0x0e"
            + "   0x0c 0x0b 0x70 0x62 0x0c 0x0e 0x0c 0x0b 0x20 0x02 0x0c 0x0e"
            + "   0x0c 0x0b 0x70 0x63 0x0c 0x0e 0x0c 0x0b 0x20 0x03 0x0c 0x0e"
            + " 0x0e)");
    },
    annotation: function () { test("hi::7", "(0x0b 0xe0 0x0b 0x70 0x68 0x69 0x0e 0x0b 0x20 0x07 0x0e 0x0e)"); },
});
function test(ionStr, expectedSexpBytes) {
    var expectedDigest = (0, testutil_1.sexpStringToBytes)(expectedSexpBytes);
    var writer = (0, ion_js_1.makeTextWriter)();
    writer.stepIn(ion_js_1.IonTypes.STRUCT);
    var hashWriter = (0, IonHash_1.makeHashWriter)(writer, (0, testutil_1.testHasherProvider)('identity'));
    hashWriter.writeFieldName("field_name");
    var reader = (0, ion_js_1.makeReader)(ionStr);
    reader.next();
    hashWriter.writeValue(reader);
    var writerActualDigest = hashWriter.digest();
    assert.deepEqual(writerActualDigest, expectedDigest);
    writer.stepOut();
    hashWriter.close();
    writer.close();
    var bytes = writer.getBytes();
    reader = (0, ion_js_1.makeReader)(bytes);
    reader.next();
    reader.stepIn();
    var hashReader = (0, IonHash_1.makeHashReader)(reader, (0, testutil_1.testHasherProvider)('identity'));
    hashReader.next();
    hashReader.next();
    var readerActualDigest = hashReader.digest();
    assert.deepEqual(readerActualDigest, expectedDigest);
}
//# sourceMappingURL=FieldnameBehaviorTest.js.map