"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var intern_1 = __importDefault(require("intern"));
var registerSuite = intern_1.default.getPlugin('interface.object').registerSuite;
var assert = intern_1.default.getPlugin('chai').assert;
var ion_js_1 = require("ion-js");
var IonHash_1 = require("../src/IonHash");
var testutil_1 = require("./testutil");
var ReaderComparer = (function () {
    function ReaderComparer(readerA, readerB) {
        this.readerA = readerA;
        this.readerB = readerB;
    }
    ReaderComparer.prototype.annotations = function () {
        assert.deepEqual(this.readerA.annotations(), this.readerB.annotations());
        return this.readerA.annotations();
    };
    ReaderComparer.prototype.bigIntValue = function () {
        assert.deepEqual(this.readerA.bigIntValue(), this.readerB.bigIntValue());
        return this.readerA.bigIntValue();
    };
    ReaderComparer.prototype.booleanValue = function () {
        assert.deepEqual(this.readerA.booleanValue(), this.readerB.booleanValue());
        return this.readerA.booleanValue();
    };
    ReaderComparer.prototype.byteValue = function () {
        assert.deepEqual(this.readerA.uInt8ArrayValue(), this.readerB.uInt8ArrayValue());
        return this.readerA.uInt8ArrayValue();
    };
    ReaderComparer.prototype.decimalValue = function () {
        assert.deepEqual(this.readerA.decimalValue(), this.readerB.decimalValue());
        return this.readerA.decimalValue();
    };
    ReaderComparer.prototype.depth = function () {
        assert.deepEqual(this.readerA.depth(), this.readerB.depth());
        return this.readerA.depth();
    };
    ReaderComparer.prototype.fieldName = function () {
        assert.deepEqual(this.readerA.fieldName(), this.readerB.fieldName());
        return this.readerA.fieldName();
    };
    ReaderComparer.prototype.intSize = function () {
        assert.deepEqual(this.readerA.intSize(), this.readerB.intSize());
        return this.readerA.intSize();
    };
    ReaderComparer.prototype.isNull = function () {
        assert.deepEqual(this.readerA.isNull(), this.readerB.isNull());
        return this.readerA.isNull();
    };
    ReaderComparer.prototype.numberValue = function () {
        assert.deepEqual(this.readerA.numberValue(), this.readerB.numberValue());
        return this.readerA.numberValue();
    };
    ReaderComparer.prototype.stringValue = function () {
        assert.deepEqual(this.readerA.stringValue(), this.readerB.stringValue());
        return this.readerA.stringValue();
    };
    ReaderComparer.prototype.timestampValue = function () {
        assert.deepEqual(this.readerA.timestampValue(), this.readerB.timestampValue());
        return this.readerA.timestampValue();
    };
    ReaderComparer.prototype.type = function () {
        assert.deepEqual(this.readerA.type(), this.readerB.type());
        return this.readerA.type();
    };
    ReaderComparer.prototype.value = function () {
        assert.deepEqual(this.readerA.value(), this.readerB.value());
        return this.readerA.value();
    };
    ReaderComparer.prototype.next = function () {
        var ionTypeA = this.readerA.next();
        var ionTypeB = this.readerB.next();
        assert.deepEqual(ionTypeA, ionTypeB);
        return ionTypeA;
    };
    ReaderComparer.prototype.stepIn = function () {
        this.readerA.stepIn();
        this.readerB.stepIn();
    };
    ReaderComparer.prototype.stepOut = function () {
        this.readerA.stepOut();
        this.readerB.stepOut();
    };
    ReaderComparer.prototype.position = function () {
        assert.deepEqual(this.readerA.position(), this.readerB.position());
        return this.readerA.position();
    };
    ReaderComparer.prototype.uInt8ArrayValue = function () {
        assert.deepEqual(this.readerA.uInt8ArrayValue(), this.readerB.uInt8ArrayValue());
        return this.readerA.uInt8ArrayValue();
    };
    return ReaderComparer;
}());
function traverse(reader) {
    for (var type = void 0; type = reader.next();) {
        switch (type) {
            case ion_js_1.IonTypes.BOOL: {
                reader.booleanValue();
                break;
            }
            case ion_js_1.IonTypes.INT: {
                reader.numberValue();
                break;
            }
            case ion_js_1.IonTypes.FLOAT: {
                reader.numberValue();
                break;
            }
            case ion_js_1.IonTypes.DECIMAL: {
                reader.decimalValue();
                break;
            }
            case ion_js_1.IonTypes.TIMESTAMP: {
                reader.timestampValue();
                break;
            }
            case ion_js_1.IonTypes.SYMBOL: {
                reader.stringValue();
                break;
            }
            case ion_js_1.IonTypes.STRING: {
                reader.stringValue();
                break;
            }
            case ion_js_1.IonTypes.CLOB: {
                reader.uInt8ArrayValue();
                break;
            }
            case ion_js_1.IonTypes.BLOB: {
                reader.uInt8ArrayValue();
                break;
            }
        }
        reader.isNull();
        if (!type.isContainer) {
            reader.value();
        }
        else {
            if (!reader.isNull()) {
                reader.stepIn();
                traverse(reader);
                reader.stepOut();
            }
        }
    }
}
registerSuite('HashReader', {
    verifyTypeBehavior: function () {
        readerCompareTest('null'
            + ' true'
            + ' 1'
            + ' -1'
            + ' 1e0'
            + ' 1d0'
            + ' 2017-01-01T00:00:00-00:00'
            + ' hello'
            + ' "hello"'
            + ' {{"hello"}}'
            + ' {{aGVsbG8=}}'
            + ' [1,2,3]'
            + ' (1 2 3)'
            + ' { c:3, a:1, b:2 }'
            + ' hello::null');
    },
    verifyNestingBehavior: function () { readerCompareTest('{ a:1, b: [1, (2 3 4), 5], c: "hello" }'); },
    emptyString: function () {
        var hashReader = (0, IonHash_1.makeHashReader)((0, ion_js_1.makeReader)(''), (0, testutil_1.testHasherProvider)('identity'));
        assert.isNull(hashReader.next());
        assert.deepEqual(hashReader.digest(), new Uint8Array());
        assert.isNull(hashReader.next());
        assert.deepEqual(hashReader.digest(), new Uint8Array());
    },
    topLevelValues: function () {
        var hashReader = (0, IonHash_1.makeHashReader)((0, ion_js_1.makeReader)('1 2 3'), (0, testutil_1.testHasherProvider)('identity'));
        assert.equal(hashReader.next(), ion_js_1.IonTypes.INT);
        assert.deepEqual(hashReader.digest(), new Uint8Array());
        assert.equal(hashReader.next(), ion_js_1.IonTypes.INT);
        assert.deepEqual(hashReader.digest(), Uint8Array.from([0x0b, 0x20, 0x01, 0x0e]));
        assert.equal(hashReader.next(), ion_js_1.IonTypes.INT);
        assert.deepEqual(hashReader.digest(), Uint8Array.from([0x0b, 0x20, 0x02, 0x0e]));
        assert.isNull(hashReader.next());
        assert.deepEqual(hashReader.digest(), Uint8Array.from([0x0b, 0x20, 0x03, 0x0e]));
        assert.isNull(hashReader.next());
        assert.deepEqual(hashReader.digest(), new Uint8Array());
    },
    initialValue: function () {
        var md5initialDigest = Uint8Array.from([0xd4, 0x1d, 0x8c, 0xd9, 0x8f, 0x00, 0xb2, 0x04, 0xe9, 0x80, 0x09, 0x98, 0xec, 0xf8, 0x42, 0x7e]);
        var hashReader = (0, IonHash_1.makeHashReader)((0, ion_js_1.makeReader)('null'), (0, testutil_1.testHasherProvider)('md5'));
        assert.deepEqual(hashReader.digest(), md5initialDigest);
        assert.equal(hashReader.next(), ion_js_1.IonTypes.NULL);
        assert.deepEqual(hashReader.digest(), md5initialDigest);
        assert.isNull(hashReader.next());
        assert.deepEqual(hashReader.digest(), Uint8Array.from([0x0f, 0x50, 0xc5, 0xe5, 0xe8, 0x77, 0xb4, 0x45, 0x1a, 0xa9, 0xfe, 0x77, 0xc3, 0x76, 0xcd, 0xe4]));
        assert.isNull(hashReader.next());
        assert.deepEqual(hashReader.digest(), md5initialDigest);
    },
    digestTooEarly: function () {
        var str = '{ a: 1, b: 2 }';
        var hashReader = (0, IonHash_1.makeHashReader)((0, ion_js_1.makeReader)(str), (0, testutil_1.testHasherProvider)('identity'));
        hashReader.next();
        hashReader.stepIn();
        assert.throws(function () { hashReader.digest(); });
    },
    digestTooLate: function () {
        var str = '{ a: 1, b: 2 }';
        var reader = (0, ion_js_1.makeReader)(str);
        reader.next();
        reader.stepIn();
        var hashReader = (0, IonHash_1.makeHashReader)(reader, (0, testutil_1.testHasherProvider)('identity'));
        hashReader.next();
        assert.throws(function () { hashReader.stepOut(); });
    },
    consumeRemainder_partialConsume: function () {
        consume(function (hr) {
            hr.next();
            hr.stepIn();
            hr.next();
            hr.next();
            hr.next();
            hr.stepIn();
            hr.next();
            hr.stepOut();
            hr.stepOut();
        });
    },
    consumeRemainder_stepInStepOutNested: function () {
        consume(function (hr) {
            hr.next();
            hr.stepIn();
            hr.next();
            hr.next();
            hr.next();
            hr.stepIn();
            hr.stepOut();
            hr.stepOut();
        });
    },
    consumeRemainder_stepInNextStepOut: function () {
        consume(function (hr) {
            hr.next();
            hr.stepIn();
            hr.next();
            hr.stepOut();
        });
    },
    consumeRemainder_stepInStepOutTopLevel: function () {
        consume(function (hr) {
            hr.next();
            assert.deepEqual(hr.digest(), new Uint8Array());
            hr.stepIn();
            assert.throws(function () { hr.digest(); });
            hr.stepOut();
        });
    },
    consumeRemainder_singleNext: function () {
        consume(function (hr) {
            hr.next();
            hr.next();
        });
    },
});
var readerCompareTest = function (ionStr) {
    var readerComparer = new ReaderComparer((0, ion_js_1.makeReader)(ionStr), (0, IonHash_1.makeHashReader)((0, ion_js_1.makeReader)(ionStr), (0, testutil_1.testHasherProvider)('identity')));
    traverse(readerComparer);
};
var consume = function (consumer) {
    var reader = (0, ion_js_1.makeReader)('(0x0b 0xb0'
        + '   0x0b 0x20 0x01 0x0e'
        + '   0x0b 0x20 0x02 0x0e'
        + '   0x0b 0xd0'
        + '     0x0c 0x0b 0x70 0x61 0x0c 0x0e 0x0c 0x0b 0x20 0x03 0x0c 0x0e'
        + '     0x0c 0x0b 0x70 0x62 0x0c 0x0e 0x0c 0x0b 0x20 0x04 0x0c 0x0e'
        + '   0x0e'
        + '   0x0b 0x20 0x05 0x0e'
        + ' 0x0e)');
    reader.next();
    var expectedBytes = (0, testutil_1.sexpToBytes)(reader);
    var hr = (0, IonHash_1.makeHashReader)((0, ion_js_1.makeReader)('[1,2,{a:3,b:4},5]'), (0, testutil_1.testHasherProvider)('identity'));
    assert.deepEqual(hr.digest(), new Uint8Array());
    consumer(hr);
    assert.deepEqual(hr.digest(), expectedBytes);
    assert.isNull(hr.next());
    assert.deepEqual(hr.digest(), new Uint8Array());
};
//# sourceMappingURL=HashReaderTest.js.map