"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var registerSuite = intern.getPlugin('interface.object').registerSuite;
var assert = intern.getPlugin('chai').assert;
var ion_js_1 = require("ion-js");
var IonHash_1 = require("../src/IonHash");
var testutil_1 = require("./testutil");
registerSuite('HashWriter', {
    topLevelValues: function () {
        var writer = (0, ion_js_1.makeTextWriter)();
        var hashWriter = (0, IonHash_1.makeHashWriter)(writer, (0, testutil_1.testHasherProvider)('identity'));
        assert.deepEqual(hashWriter.digest(), new Uint8Array());
        hashWriter.writeInt(1);
        assert.deepEqual(hashWriter.digest(), Uint8Array.from([0x0b, 0x20, 0x01, 0x0e]));
        hashWriter.writeInt(2);
        assert.deepEqual(hashWriter.digest(), Uint8Array.from([0x0b, 0x20, 0x02, 0x0e]));
        hashWriter.writeInt(3);
        assert.deepEqual(hashWriter.digest(), Uint8Array.from([0x0b, 0x20, 0x03, 0x0e]));
        assert.deepEqual(hashWriter.digest(), new Uint8Array());
        assert.deepEqual(writer.getBytes(), Uint8Array.from([0x31, 0x0a, 0x32, 0x0a, 0x33]));
    },
    initialValue: function () {
        var md5initialDigest = Uint8Array.from([0xd4, 0x1d, 0x8c, 0xd9, 0x8f, 0x00, 0xb2, 0x04, 0xe9, 0x80, 0x09, 0x98, 0xec, 0xf8, 0x42, 0x7e]);
        var writer = (0, ion_js_1.makeTextWriter)();
        var hashWriter = (0, IonHash_1.makeHashWriter)(writer, (0, testutil_1.testHasherProvider)('md5'));
        assert.deepEqual(hashWriter.digest(), md5initialDigest);
        hashWriter.writeNull(ion_js_1.IonTypes.NULL);
        assert.deepEqual(hashWriter.digest(), Uint8Array.from([0x0f, 0x50, 0xc5, 0xe5, 0xe8, 0x77, 0xb4, 0x45, 0x1a, 0xa9, 0xfe, 0x77, 0xc3, 0x76, 0xcd, 0xe4]));
        assert.deepEqual(hashWriter.digest(), md5initialDigest);
    },
    writeScalarNull: function () {
        var writer = (0, ion_js_1.makeTextWriter)();
        var hashWriter = (0, IonHash_1.makeHashWriter)(writer, (0, testutil_1.testHasherProvider)('identity'));
        hashWriter.writeNull(ion_js_1.IonTypes.STRING);
        var writeNullDigest = hashWriter.digest();
        hashWriter.writeString(null);
        var writeStringDigest = hashWriter.digest();
        assert.deepEqual(writeStringDigest, writeNullDigest);
    },
    digestTooEarly: function () {
        var hashWriter = (0, IonHash_1.makeHashWriter)((0, ion_js_1.makeBinaryWriter)(), (0, testutil_1.testHasherProvider)('identity'));
        hashWriter.stepIn(ion_js_1.IonTypes.STRUCT);
        hashWriter.writeFieldName('a');
        hashWriter.writeInt(5);
        assert.throws(function () { hashWriter.digest(); });
    },
    digestTooLate: function () {
        var writer = (0, ion_js_1.makeBinaryWriter)();
        writer.stepIn(ion_js_1.IonTypes.STRUCT);
        var hashWriter = (0, IonHash_1.makeHashWriter)(writer, (0, testutil_1.testHasherProvider)('identity'));
        assert.throws(function () { hashWriter.stepOut(); });
    },
});
//# sourceMappingURL=HashWriterTest.js.map