"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
var registerSuite = intern.getPlugin('interface.object').registerSuite;
var assert = intern.getPlugin('chai').assert;
var fs_1 = require("fs");
var ion_js_1 = require("ion-js");
var IonHash_1 = require("../src/IonHash");
var ionhash = __importStar(require("../src/IonHash"));
var testutil_1 = require("./testutil");
var binaryReaderDigester = function (ionData, algorithm, hasherLog) {
    var reader = (0, ion_js_1.makeReader)(ionData);
    var writer = (0, ion_js_1.makeBinaryWriter)();
    reader.next();
    writer.writeValue(reader);
    writer.close();
    var ionBinary = writer.getBytes();
    readerDigester((0, ion_js_1.makeReader)(ionBinary), algorithm, hasherLog);
};
var textReaderDigester = function (ionData, algorithm, hasherLog) {
    readerDigester((0, ion_js_1.makeReader)(ionData), algorithm, hasherLog);
};
function readerDigester(reader, algorithm, hasherLog) {
    function traverse(reader) {
        for (var type = void 0; type = reader.next();) {
            if (type.isContainer && !reader.isNull()) {
                reader.stepIn();
                traverse(reader);
                reader.stepOut();
            }
        }
    }
    var hashReader = (0, IonHash_1.makeHashReader)(reader, (0, testutil_1.testHasherProvider)(algorithm, hasherLog));
    traverse(hashReader);
    hashReader.digest();
}
var readerSkipDigester = function (ionData, algorithm, hasherLog) {
    var hashReader = (0, IonHash_1.makeHashReader)((0, ion_js_1.makeReader)(ionData), (0, testutil_1.testHasherProvider)(algorithm, hasherLog));
    hashReader.next();
    hashReader.next();
    hashReader.digest();
};
var binaryWriterDigester = function (ionData, algorithm, hasherLog) {
    writerDigester((0, ion_js_1.makeBinaryWriter)(), ionData, algorithm, hasherLog);
};
var textWriterDigester = function (ionData, algorithm, hasherLog) {
    writerDigester((0, ion_js_1.makeTextWriter)(), ionData, algorithm, hasherLog);
};
function writerDigester(writer, ionData, algorithm, hasherLog) {
    var reader = (0, ion_js_1.makeReader)(ionData);
    reader.next();
    var hashWriter = (0, IonHash_1.makeHashWriter)(writer, (0, testutil_1.testHasherProvider)(algorithm, hasherLog));
    hashWriter.writeValue(reader);
    hashWriter.digest();
}
var digestFunctionDigester = function (ionData, algorithm, hasherLog) {
    var value = (0, ion_js_1.load)(ionData);
    var digest = ionhash.digest(value, algorithm);
    hasherLog.push('final_digest::(' + (0, testutil_1.toHexString)(digest) + ')');
};
var digesters = {
    BinaryReader: binaryReaderDigester,
    BinaryWriter: binaryWriterDigester,
    ReaderSkip: readerSkipDigester,
    TextReader: textReaderDigester,
    TextWriter: textWriterDigester,
    digestFunction: digestFunctionDigester,
};
function test(ionData, algorithm, expect, digester) {
    var expectedHasherLog = getExpectedHasherLog(expect);
    var actualHasherLog = [];
    digester(ionData, algorithm, actualHasherLog);
    if (expectedHasherLog.length == 1
        && expectedHasherLog[0].startsWith('final_digest::')) {
        assert.deepEqual('final_' + actualHasherLog.pop(), expectedHasherLog[0]);
    }
    else if (actualHasherLog.length == 1
        && actualHasherLog[0].startsWith('final_digest::')) {
        assert.deepEqual(actualHasherLog[0], 'final_' + expectedHasherLog.pop());
    }
    else {
        if (algorithm == 'md5') {
            expectedHasherLog = expectedHasherLog.filter(function (entry) { return entry.startsWith('digest::'); });
        }
        assert.deepEqual(actualHasherLog, expectedHasherLog);
    }
}
var suites = {};
for (var digester in digesters) {
    suites[digester] = {};
}
var ionTests = (0, fs_1.readFileSync)('tests/ion_hash_tests.ion', 'utf8');
var testCount = 0;
var reader = (0, ion_js_1.makeReader)(ionTests);
var _loop_1 = function (type) {
    var testName = '';
    if (reader.annotations().length > 0) {
        testName = reader.annotations()[0];
    }
    var ionData;
    reader.stepIn();
    reader.next();
    if (reader.fieldName() == '10n') {
        ionData = (0, testutil_1.sexpToBytes)(reader, { asIonBinary: true });
    }
    else {
        ionData = (0, testutil_1.readerToString)(reader);
        if (!testName) {
            testName = ionData;
        }
    }
    reader.next();
    reader.stepIn();
    var expects = {};
    for (var t = void 0; t = reader.next();) {
        var algorithm = reader.fieldName();
        if (algorithm !== null) {
            expects[algorithm] = (0, testutil_1.readerToString)(reader);
        }
    }
    reader.stepOut();
    reader.stepOut();
    var _loop_2 = function (algorithm) {
        var theTestName = testName;
        if (algorithm != 'identity') {
            theTestName = testName + '.' + algorithm;
        }
        var _loop_3 = function (digester) {
            if (!(digester == 'digestFunction' && algorithm == 'identity')) {
                suites[digester][theTestName] = function () {
                    test(ionData, algorithm, expects[algorithm], digesters[digester]);
                };
            }
        };
        for (var digester in digesters) {
            _loop_3(digester);
        }
    };
    for (var algorithm in expects) {
        _loop_2(algorithm);
    }
    testCount++;
};
for (var type = void 0; type = reader.next();) {
    _loop_1(type);
}
(0, testutil_1.writeln)("testCount: " + testCount);
for (var suite in suites) {
    registerSuite('IonHashTests.' + suite, suites[suite]);
}
function getExpectedHasherLog(expect) {
    var log = [];
    var reader = (0, ion_js_1.makeReader)(expect);
    reader.next();
    reader.stepIn();
    for (var type = void 0; type = reader.next();) {
        var annotation = reader.annotations()[0];
        var byteString = annotation + '::(' + (0, testutil_1.toHexString)((0, testutil_1.sexpToBytes)(reader)) + ')';
        if (annotation == 'final_digest') {
            log = [byteString];
        }
        else {
            log.push(byteString);
        }
    }
    return log;
}
//# sourceMappingURL=IonHashTests.js.map