"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.writeln = exports.write = exports.toHexString = exports.readerToString = exports.sexpToBytes = exports.sexpStringToBytes = exports.testHasherProvider = void 0;
var ion_js_1 = require("ion-js");
var crypto_1 = require("crypto");
var IdentityHasher = (function () {
    function IdentityHasher(log) {
        if (log === void 0) { log = []; }
        this.log = log;
        this.allBytes = [];
    }
    IdentityHasher.prototype.update = function (bytes) {
        for (var i = 0; i < bytes.length; i++) {
            this.allBytes.push(bytes[i]);
        }
        this.log.push('update::(' + toHexString(bytes) + ')');
    };
    IdentityHasher.prototype.digest = function () {
        var digest = new Uint8Array(this.allBytes);
        this.log.push('digest::(' + toHexString(digest) + ')');
        this.allBytes = [];
        return Uint8Array.from(digest);
    };
    return IdentityHasher;
}());
var CryptoTestHasher = (function () {
    function CryptoTestHasher(algorithm, log) {
        if (log === void 0) { log = []; }
        this.algorithm = algorithm;
        this.log = log;
        this.hash = (0, crypto_1.createHash)(algorithm);
    }
    CryptoTestHasher.prototype.update = function (bytes) {
        this.hash.update(bytes);
    };
    CryptoTestHasher.prototype.digest = function () {
        var digest = this.hash.digest();
        this.log.push('digest::(' + toHexString(digest) + ')');
        this.hash = (0, crypto_1.createHash)(this.algorithm);
        return digest;
    };
    return CryptoTestHasher;
}());
function testHasherProvider(algorithm, log) {
    return function () {
        if (algorithm == 'identity') {
            return new IdentityHasher(log);
        }
        else {
            return new CryptoTestHasher(algorithm, log);
        }
    };
}
exports.testHasherProvider = testHasherProvider;
function sexpStringToBytes(sexpStr) {
    var reader = (0, ion_js_1.makeReader)(sexpStr);
    reader.next();
    return sexpToBytes(reader);
}
exports.sexpStringToBytes = sexpStringToBytes;
function sexpToBytes(reader, options) {
    if (options === void 0) { options = { asIonBinary: false }; }
    var bytes;
    if (options.asIonBinary) {
        bytes = [0xE0, 0x01, 0x00, 0xEA];
    }
    else {
        bytes = [];
    }
    reader.stepIn();
    for (var type = void 0; type = reader.next();) {
        bytes.push(reader.numberValue());
    }
    reader.stepOut();
    return Uint8Array.from(bytes);
}
exports.sexpToBytes = sexpToBytes;
function readerToString(reader) {
    var writer = (0, ion_js_1.makeTextWriter)();
    writer.writeValue(reader);
    writer.close();
    return String.fromCharCode.apply(null, writer.getBytes());
}
exports.readerToString = readerToString;
function toHexString(byteArray) {
    var sb = '';
    byteArray.forEach(function (b) {
        if (sb != '') {
            sb += ' ';
        }
        sb += ('0' + (b & 0xFF).toString(16)).slice(-2);
    });
    return sb;
}
exports.toHexString = toHexString;
function write(s) { process.stdout.write(s); }
exports.write = write;
function writeln(s) {
    if (s === void 0) { s = ""; }
    write(s + "\n");
}
exports.writeln = writeln;
//# sourceMappingURL=testutil.js.map